import React from 'react';
import {inject, observer} from "mobx-react"
import Radio from 'antd/lib/radio';
import style from './editRepeatSchedule.scss';

const RadioGroup = Radio.Group;

@inject('definedFunc')
@observer

/**
 * @model
 * @description 自定义Modal 删除重复组件
 */

class EditRepeatSchedule extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      value: 'current',
    };
  }

  onChange = (e) => {
    this.setState({
      value: e.target.value,
    });
  }

  confirmFunc = () => {
    this.props.definedFunc.setEditRepeat(this.state.value)
    this.props.closeModal()
  }

  render() {
    const radioStyle = {
      display: 'block',
      marginTop: '15px',
      marginBottom: '15px',
    };
    const CalendarEditorParams = {
      day: this.props.day,
      type: this.state.value,
    };
    return (<div className={style.deleteRepeatSchedule} >
      <div className={style.title} >
        你正在编辑重复事件
      </div>
      <div className={style.content}>
        <RadioGroup onChange={this.onChange} value={this.state.value}>
          <Radio style={radioStyle} value={'current'}>&nbsp;&nbsp;仅编辑当前事件</Radio>
          <Radio style={radioStyle} value={'current_future'}>&nbsp;&nbsp;编辑当前事件及后续此重复事件</Radio>
          <Radio style={radioStyle} value={'all'}>&nbsp;&nbsp;编辑所有此重复事件</Radio>
        </RadioGroup>
        <p className={style.center}>
          <a
            className={`${style.btn} ${style['btn-cancel']}`}
            onClick={(e) => {
              e.stopPropagation();
              this.props.closeModal()
            }}
          >取消</a>
          <a
            className={`${style.btn} ${style['btn-confirm']}`}
            onClick={(e) => {
              e.stopPropagation();
              this.confirmFunc();
            }}
          >确定</a>
        </p>
      </div>
    </div>);
  }
}

export default EditRepeatSchedule;
