import React from 'react';
import style from './userDefinedEvent.scss';
import {tost,tosts, Modal, Modals, Scroll} from 'karaui';

const {errorTost} = tosts
const {Confirm} = Modals

const colorArr = [
  '#fced88',
  '#d9ebb1',
  '#9acf7e',
  '#96d0de',
  '#99bbe1',
  '#f0c5a3',
  '#f5adbb',
  '#c7ad92',
  '#d0a49b',
  '#d5a8c9',
];
const iconArr = [
  'kccfont i-peixun1',
  'kccfont i-tanpan',
  'kccfont i-xuexi',
  'kccfont i-julebu',
  'kccfont i-xihao',
  'kccfont i-xiuxian',
  'kccfont i-jiaban',
  'kccfont i-shengri1',
  'kccfont i-tuanduijianshe',
  'kccfont i-chucha1',
];

export default class UserDefinedEvent extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      valueLength: 0, // 输入框字数
      maxLength: false,
      activeIcon: 0, // 当前icon
      activeColor: 0,
      delete: false, // 删除
      edit: false, // 编辑
      eventId: '', // 事件id
      iconCode: 'kccfont i-peixun1', // 被选中icon
      colorCode: '#fced88',
      selectColor: '', // 编辑已保存事件color
      selectIcon: '',
      placeHolder: false,
      holderText: '请输入自定义时间类型名称',
      inputValue: '',
      eventList: [],
    };
  }

  componentDidMount() {
    this.canGetList();
  }

  canGetList = () => {
    this.props.httpAgent.getUserDefined().then(res => {
      if (res && res.resultCode === '000000') {
        this.setState({eventList: res.scheduleEventTypeInfoList});
      } else {
        this.setState({eventList: []});
      }
    });
  }
  handleOnChange = (e) => {
    const sign = e.target.value;
    if (sign !== '') {
      this.setState({placeHolder: false, holderText: '请输入自定义时间类型名称'});
    }
    this.setState({valueLength: e.target.value.length});
  }
  closeEvent = () => {
    this.input.value = '';
    this.setState({
      valueLength: 0,
      eventId: '',
    });
  }
  handleDelete = (item) => {
    this.setState({ delete: true, eventId: item.id })
  }

  // 保存
  save = (id, name, icon, color) => {
    if (this.input.value === '') {
      this.setState({placeHolder: true, holderText: '名称不可为空'});
    } else {
      this.props.httpAgent.saveEvent(id, name, icon, color).then(res => {
        if (res && res.resultCode === '000000') {
          this.canGetList();
          this.closeEvent();
          this.setState({
            activeIcon: 0,
            activeColor: 0,
            selectColor: '',
            selectIcon: '',
          });
        }
      });
    }
  }

  // 确定
  onConfirm = () => {
    this.props.httpAgent.deleteEvent(this.state.eventId).then(res => {
      if (res && res.resultCode === '000000') {
        this.onCancel();
        this.canGetList();
        tost('删除成功')
      }
    })
  }

  // 取消
  onCancel = () => {
    this.setState({ delete: false })
  }

  render() {
    const saveName = this.input && this.input.value ? this.input.value : null;
    return (<div className={`${style['event-contain']}`}>
      <div className={`${style['event-head']} ${style.clearfix}`}>
        <span>自定义事件类型</span>
        <span
          className={'kccfont i-close'}
          onClick={() => {
            this.props.closeEvent()
          }}
        />
      </div>
      {/* 展示区域 */}
      <div className={style['event-info']}>
        <Scroll>
          {
            <ul className={style['event-info-bd']}>
              {this.state.eventList.length !== 0 ? this.state.eventList.map(item => <li key={item.id} className={style['event-info-list']}>
                <span className={item.icon} style={{color: item.color}}/>
                <span>{item.etname}</span>
                <p className={style['event-edit']}>
                  {/* 编辑已保存事件 */}
                  <i
                    className={'kccfont i-edit1'}
                    onClick={() => {
                      this.input.value = item.etname;
                      this.setState({
                        valueLength: item.etname.length,
                        selectColor: item.color,
                        selectIcon: item.icon,
                        eventId: item.id,
                        activeIcon: -1,
                        activeColor: -1,
                        placeHolder: false,
                      });
                    }}
                  />
                  {/* 删除已有事件 */}
                  <i
                    className={'kccfont i-close'}
                    onClick={() => {
                      this.handleDelete(item);
                    }}
                  />
                </p>
              </li>) :
              <li className={style['no-event']}>
                您还未添加自定义事件类型
              </li>}
            </ul>
          }
        </Scroll>
      </div>
      {/* 编辑区域 */}
      <div className={style['event-line']}/>
      <div className={style['event-text']}>
        <div className={style['event-name']}>
          <span className={style['event-title']}>
            名称
          </span>
          <input
            ref={(e) => {this.input = e;}}
            type="text"
            placeholder={this.state.holderText}
            maxLength="10"
            onChange={e => this.handleOnChange(e)}
            className={this.state.placeHolder ? style['light-color'] : ''}
          />
          <span className={style['event-count']}>
            {this.state.valueLength}/10
          </span>
        </div>
        <div className={style['event-icon']}>
          <span className={style['event-title']}>
            图标
          </span>
          <ul className={style['icon-choice']}>
            {iconArr.map((item, idx) => {
              const show = this.state.activeIcon !== idx ? '' : style.show;
              const selectShow = this.state.selectIcon === item ? style.show : '';
              return (<li
                key={item}
                className={item}
                onClick={() => {
                  this.setState({
                    activeIcon: this.state.activeIcon === idx ? -1 : idx,
                    iconCode: iconArr[idx],
                    selectIcon: '',
                  });
                }}
              >
                <span className={`${style['icon-select']} ${'kccfont i-xuanzhong2'} ${selectShow} ${show}`}/>
              </li>);
            })}
          </ul>
        </div>
        <div className={style['event-color']}>
          <span className={style['event-title']}>
            颜色
          </span>
          <ul className={style['color-choice']}>
            {colorArr.map((item, idx) => {
              const show = this.state.activeColor !== idx ? '' : style.show;
              const selectShow = this.state.selectColor === item ? style.show : '';
              return (<li
                key={item}
                style={{backgroundColor: item}}
                onClick={() => {
                  this.setState({
                    activeColor: this.state.activeColor === idx ? -1 : idx,
                    colorCode: colorArr[idx],
                    selectColor: '',
                  });
                }}
              >
                <span className={`${style['color-select']} ${'kccfont i-xuanzhong2'} ${show} ${selectShow}`}/>
              </li>);
            })}
          </ul>
        </div>
      </div>
      <div className={style['event-btm']}>
        <div
          className={style['event-btn']}
          onClick={() => {
            this.save(this.state.eventId, saveName, this.state.iconCode, this.state.colorCode);
          }}
        >
          确认
        </div>
      </div>
      <Modal show={this.state.delete}>
        <Confirm
          onConfirm={this.onConfirm}
          onCancel={this.onCancel}
          message='删除此事件类型的同时将一并删除其相关日程事件是否继续删除?'
          confirmButton='确定'
          cancelButton='取消'
          className={style.confirmBtn}
        />
      </Modal>
    </div>);
  }
}
