/**
 * Created by Berlin on 2018/6/27.
 */
import React from 'react';
import {inject, observer} from "mobx-react"
import css from './calendarEditor.scss'
import Input from 'antd/lib/input'
import DatePicker from 'antd/lib/date-picker'
// import 'antd/lib/date-picker/style/css'
import locale from 'antd/lib/date-picker/locale/zh_CN';
import moment from 'moment';
import 'moment/locale/zh-cn';
import {tost, tosts, Modal, Scroll} from 'karaui'
import Loading from '../Loading/loading'
import EventType from './eventType/eventType'; // 事件类型
import Notice from './notice/notice'; // 提醒方式
import Repeat from './repeat/repeat'; // 重复方式
import Participants from './participants/participants'; // 参与人
import AddContacter from './participants/AddContacter/addContacter'; // 添加参与人
import Remark from './remark/remark'; // 备注
import UserDefinedEvent from './UserDefinedEvent/userDefinedEvent'; // 自定义事件
import EditRepeatSchedule from './EditRepeatSchedule/editRepeatSchedule'; // 编辑重复事件
import DeleteRepeatSchedule  from './DeleteRepeatSchedule/deleteRepeatSchedule'; // 删除重复事件

const {errorTost} = tosts

const Textarea =Input.TextArea
moment.locale('zh-cn');

@inject('calendarStore')
@inject('configStore')
@inject('definedFunc')
@observer

export default class CalendarEditor extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      allDay: false, //全天
      isRemind: false,
      isRepeat: false,
      isContractor: false,
      isRemark: false,
      modalShow: false,
      editShow: false,
      delShow: false,
      inputValue: '', // 事件内容
      showDefined: false, //自定义事件
      remindType: [], // 提醒方式
      addItem: false, // 添加参与人
      beginTime: '', // 开始事件
      endTime: '', // 结束事件
      startTime: '', // 用于记录变更时间
      end: '',
      detailEdit: false, // 编辑状态
      editRepeatType: 'noRepeat', // 编辑事件类型
      eventId: '', // 事件ID
      correlationEventId: '', // 事件关联ID
      scheduleDetail: {}, // 事件详情
      isSubmit: false, // 提交
    }
    this.inputStyle = {
      width: '91%',
      border: 'none',
      overflowY: 'visible',
      resize: 'none',
      outline: 'none',
      padding: '0',
      borderRadius: 0,
      borderBottom: '1px solid #e5e5e5',
      background: '#fff',
      fontSize: '13px',
      color: '#949494',
    }
    this.btn = [
      { name: '提醒', icon: 'kccfont i-shi1', type: 'isRemind' },
      { name: '重复', icon: 'kccfont i-shuaxin', type: 'isRepeat' },
      { name: '参与人', icon: 'kccfont i-group', type: 'isContractor' },
      { name: '备注', icon: 'kccfont i-edit', type: 'isRemark' },
    ]
    this.repeatBtn = [
      { name: '提醒', icon: 'kccfont i-shi1', type: 'isRemind' },
      { name: '参与人', icon: 'kccfont i-group', type: 'isContractor' },
      { name: '备注', icon: 'kccfont i-edit', type: 'isRemark' },
    ]
  }

  componentWillMount() {
    const {scheduleId} = this.props.scheduleInfo
    const {eventId, isRepeat, repeatType} = this.props.editInfo;
    this.props.httpAgent.getUser().then(res => {
      if (res && res.resultCode === '000000') {
        this.props.calendarStore.getUserInfo(res);
      }
    })
    if (scheduleId && scheduleId !== '') {
      this.props.httpAgent.getScheduleDetail(scheduleId).then(res => {
        if (res && res.resultCode === '000000') {
          this.props.calendarStore.getScheduleDetail(res.result);
          this.initDetail(res.result);
        } else {
          errorTost('网络错误', 5);
        }
      });
    }
    if (eventId && eventId !== '') {
      this.props.httpAgent.getScheduleDetail(eventId).then(res => {
        if (res && res.resultCode === '000000') {
          this.props.calendarStore.getScheduleDetail(res.result);
          this.initDetail(res.result);
        } else {
          errorTost('网络错误', 5);
        }
      });
      this.props.definedFunc.setEditRepeat(repeatType)
      this.setState({ editRepeatType: isRepeat ? repeatType : 'noRepeat', detailEdit: true })
    }
    this.getEventList()
  }

  componentDidMount() {
    this.initTime()
  }

  componentDidUpdate() {
    if (this.props.definedFunc.editRepeat && this.props.definedFunc.editRepeat !== this.state.editRepeatType && this.props.definedFunc.editRepeat !== '') {
      if (this.props.definedFunc.editRepeat === 'current') {
        this.setState({ isRepeat: false })
      }
      this.setState({ detailEdit: true, editRepeatType: this.props.definedFunc.editRepeat})
    }
  }

  componentWillUnmount() {
    this.props.definedFunc.initDate()
    this.props.calendarStore.initSchedule()
  }

  // 编辑
  editEvent = () => {
    if (this.state.isRepeat) {
      // 重复事件
      this.isShowEdit();
    } else {
      this.setState({ detailEdit: true });
    }
  }

  // 删除
  deleteEvent = () => {
    if (this.state.isRepeat) {
      // 重复事件
      this.isShowDel();
    } else {
      this.props.httpAgent.deleteSchedule(this.state.eventId).then(res => {
        if (res && res.resultCode === '000000') {
          tost('删除成功')
          if (this.props.closeCalendar) {
            this.props.config.saveSuccess()
            this.props.closeCalendar()
          }
        } else {
          errorTost(res.resultMessage);
        }
      })
    }
  }

  // 显示 隐藏编辑模态框
  isShowEdit = (param) => {
    if (param === 'hide') {
      this.setState({ editShow: false })
    } else {
      this.setState({ editShow: true })
    }
  }

  // 显示 隐藏编删除态框
  isShowDel = (param) => {
    if (param === 'hide') {
      this.setState({ delShow: false })
    } else {
      this.setState({ delShow: true })
    }
  }

  // 初始化详情
  initDetail = (detail) => {
    const {content, isAllDay, beginTime, endTime, remind, invitees, remark, repeatType, id, correlationEventId, channelId, repeatEndDate, repeatIsOver} = detail
    this.setState({
      scheduleDetail: detail,
      eventId: id,
      correlationEventId: correlationEventId,
      inputValue: content, // 事件内容
      allDay: isAllDay === 'yes' ? true : false, // 全天
      beginTime: moment(beginTime),
      startTime: moment(beginTime),
      endTime: moment(endTime),
      end: moment(endTime),
    })
    this.props.definedFunc.setEventContent(content) // 更新store
    this.props.definedFunc.setRepeatType(repeatType, repeatEndDate) // 重复
    this.props.definedFunc.setRepeatIsOver(repeatIsOver) // 重复
    if (remind) {
      this.choiceBtn('isRemind')
    }
    if (invitees) {
      this.choiceBtn('isContractor')
    }
    if (remark) {
      this.choiceBtn('isRemark')
    }
    if (repeatType && this.state.editRepeatType !== 'current') {
      this.choiceBtn('isRepeat')
    }
    if (channelId && channelId !== '') {
      this.props.definedFunc.setChannel(channelId)
    }
  }

  // 初始化时间
  initTime = () => {
    const min = new Date().getMinutes();
    let now = moment().add(1, 'h').subtract(min, 'm');
    let end = moment().add(2, 'h').subtract(min, 'm');
    // 处理时间初始化问题 传递时间 按照传递的时间进行初始化
    const {createDate} = this.props.scheduleInfo;
    if (createDate && createDate.length > 1) {
      if (createDate.length === 8) {
        const hour = now.hour().toString().length > 1 ? now.hour() : 0 + now.hour().toString();
        const minute = now.minute().toString().length > 1 ?
          now.minute() : 0 + now.minute().toString();
        const second = now.second().toString().length > 1 ?
          now.second() : 0 + now.second().toString();
        now = moment(`${createDate} ${hour}:${minute}:${second}`, 'YYYYMMDD HH:mm:ss');
        end = moment(`${createDate} ${hour}:${minute}:${second}`, 'YYYYMMDD HH:mm:ss').add(1, 'h');
      } else {
        now = moment(createDate, 'YYYYMMDDHHmmss');
        end = moment(createDate, 'YYYYMMDDHHmmss').add(1, 'h');
      }
    }
    this.setState({ beginTime: now, endTime: end });
  }

  // 操作按钮
  choiceBtn = (type) => {
    if (type === 'isRemind') {
      this.setState({ isRemind: !this.state.isRemind })
    } else if (type === 'isRepeat') {
      this.setState({ isRepeat: !this.state.isRepeat })
    } else if (type === 'isContractor') {
      this.setState({ isContractor: !this.state.isContractor })
    } else if (type === 'isRemark') {
      this.setState({ isRemark: !this.state.isRemark })
    }
  }

  // 关闭下拉框
  closeModal = (isExpend) => {
    if (isExpend === 'show') {
      this.setState({ modalShow: true })
    } else {
      this.setState({ modalShow: false })
    }
  }

  // 事件内容
  handleChange = e => {
    if (e.target) {
      this.setState({ inputValue: e.target.value })
      this.props.definedFunc.setEventContent(e.target.value)
    }
  }

  // 关闭自定义事件
  closeEvent = (isShow) => {
    if (isShow === 'show') {
      this.setState({ showDefined: true })
    } else {
      this.setState({ showDefined: false, modalShow: false })
      this.getEventList()
    }
  }

  // 获取事件类型
  getEventList = () => {
    this.props.httpAgent.getEventLists().then(res => {
      this.props.calendarStore.setEventLists(res.scheduleEventTypeInfoList);
    })
  }

  // 添加参与人
  addNew = (param) => {
    if (param === 'close') {
      this.setState({ addItem: false })
    } else {
      this.setState({ addItem: true })
    }
  }

  // 开始
  onStartChange = (data) => {
    let endDate = moment(data).add(1, 'h');
    if (!data) {
      endDate = null;
    }
    this.setState({
      beginTime: data,
      endTime: endDate,
    });
  }

  // 结束
  onEndChange = (data) => {
    this.setState({ endTime: data })
  }

  // 不可选择的开始日期
  disableBegin = (start) => {
    if (!start) {
      return false;
    }
    const startVal = moment(start).set({ hour: 0, minute: 0, second: 0 });
    const current = moment();
    if (current.get('year') === startVal.get('year') && current.get('month') === startVal.get('month') && current.get('date') === startVal.get('date')) {
      return false;
    }
    return start.valueOf() <= current.valueOf();
  }

  // 不可选择的结束日期
  disableEnd = (end) => {
    const endValue = this.state.endTime;
    if (!end || !endValue) {
      return false;
    }
    return end.valueOf() <= endValue.valueOf() - 86400000;
  }

  // 保存日程
  saveCalendar = () => {
    const {
      eventContent,
      eventType,
      repeatType,
      repeatIsOver,
      repeatEndDate,
      remindTimes,
      remindTypes,
      invitees,
      remark,
      isCreateChat,
      setChannel, //设置channelId
    } = this.props.definedFunc;
    let scheduleEvent // 入参对象
    const content = this.state.inputValue; // 事件内容
    const isAllDay = this.state.allDay; // 是否全天
    const beginTime = moment(this.state.beginTime).format('YYYYMMDD HH:mm:ss') === 'Invalid date' ? '' : moment(this.state.beginTime).format('YYYYMMDD HH:mm:ss');
    const endTime = moment(this.state.endTime).format('YYYYMMDD HH:mm:ss') === 'Invalid date' ? '' : moment(this.state.endTime).format('YYYYMMDD HH:mm:ss');
    const eventTypeId = eventType;
    scheduleEvent = {
      content,
      isAllDay: isAllDay || isAllDay === 'yes' ? 'yes' : 'no',
      beginTime,
      endTime,
      eventTypeId,
    }
    // 创建前校验
    if (content === '') {
      errorTost('请填写事件内容', 5);
      return
    } else if (beginTime === '' || endTime === '') {
      errorTost('请选择起止时间', 5);
      return
    }
    // 重复
    if (this.state.isRepeat) {
      const type = repeatType === '' ? null : repeatType
      const endDate = repeatIsOver === 'yes' ? repeatEndDate : null
      Object.assign(scheduleEvent, {repeatType: type, repeatIsOver, repeatEndDate: endDate});
    }
    // 提醒
    if (this.state.isRemind) {
      if (remindTimes.length !== 0) {
        Object.assign(scheduleEvent, {remindTimes: remindTimes.sort()});
      }
      if (remindTypes.length !== 0) {
        Object.assign(scheduleEvent, {remindTypes: remindTypes.sort()});
      }
    }
    // 备注
    if (this.state.isRemark) {
      if (remark !== '') {
        Object.assign(scheduleEvent, {remark});
      }
    }
    if (this.state.eventId !== '') {
      // 编辑
      if (this.state.editRepeatType === 'noRepeat') {
        Object.assign(scheduleEvent, {id: this.state.eventId}, {invitees: invitees.sort()})
        this.setState({ isSubmit: true })
        const msg = invitees.length > 1 ? '编辑成功，已通知参与人' : '编辑成功';
        this.saveApi(scheduleEvent, 'edit', msg);
      } else {
        const beginInterval = (new Date(this.state.beginTime).getTime() - new Date(this.state.startTime).getTime())
        const endInterval = (new Date(this.state.endTime).getTime() - new Date(this.state.end).getTime())
        Object.assign(
          scheduleEvent,
          {id: this.state.eventId},
          {correlationEventId: this.state.correlationEventId},
          {invitees: invitees.sort()},
        )
        let param = {
          scheduleEvent,
          method: 'modify',
          type: this.state.editRepeatType,
          changeDate: moment(new Date().getTime()).format('YYYYMMDD'),
          beginTimerInterval: beginInterval,
          endTimeInterval: endInterval,
        }
        this.setState({ isSubmit: true })
        this.editApi(param)
      }
    } else {
      // 新增
      let msg = '日程创建成功'
      if (this.state.isContractor) {
        // 参与人
        if (invitees.length !== 0) {
          Object.assign(scheduleEvent, {invitees: invitees.sort()});
          msg = '创建成功，已通知参与人'
        }
        this.setState({ isSubmit: true })
        if (isCreateChat && invitees.length !== 0) {
          const name = `${beginTime.substr(0, 8)} - ${content}`
          this.props.httpAgent.createGroupChat(invitees, name).then(res  => {
            if (res && res.resultCode === '000000') {
              setChannel(res.channelInfo.id)
              Object.assign(scheduleEvent, {channelId: res.channelInfo.id});
              this.saveApi(scheduleEvent, false, msg);
            } else {
              this.setState({ isSubmit: false })
              errorTost(res.resultMessage)
            }
          })
        } else {
          this.saveApi(scheduleEvent, false, msg);
        }
      } else {
        this.setState({ isSubmit: true })
        this.saveApi(scheduleEvent, false, msg);
      }
    }
  }

  // api
  saveApi = (param, type, msg) => {
    const func = type === 'edit' ? this.props.httpAgent.editSchedule(param) : this.props.httpAgent.saveSchedule(param);
    func.then(res => {
      this.setState({ isSubmit: false })
      if (res && res.resultCode === '000000') {
        tost(msg)
        if (this.props.closeCalendar) {
          this.props.config.saveSuccess()
          this.props.closeCalendar()
        }
      } else if (res && res.resultCode !== '000000') {
        errorTost(res.resultMessage, 5)
      } else {
        errorTost('网络错误', 5)
      }
    })
  }

  editApi = (param) => {
    this.props.httpAgent.modifyRepeat(param).then(res => {
      this.setState({ isSubmit: false })
      if (res && res.resultCode === '000000') {
        tost('保存成功')
        if (this.props.closeCalendar) {
          this.props.config.saveSuccess()
          this.props.closeCalendar()
        }
      } else if (res && res.resultCode !== '000000') {
        errorTost(res.resultMessage, 5)
      } else {
        errorTost('网络错误', 5)
      }
    })
  }

  deleteApi = (val) => {
    const param = {
      scheduleEvent: {
        id: this.state.eventId,
        correlationEventId: this.state.correlationEventId,
      },
      method: 'delete',
      type: val,
      changeDate: moment(new Date().getTime()).format('YYYYMMDD'),
    }
    this.props.httpAgent.modifyRepeat(param).then(res => {
      if (res && res.resultCode === '000000') {
        tost('删除成功')
        if (this.props.closeCalendar) {
          this.props.config.saveSuccess()
          this.props.closeCalendar()
        }
      } else {
        errorTost(res.resultMessage)
      }
    })
    this.isShowDel('hide')
  }

  render() {
    const {scheduleDetail} = this.props.calendarStore;
    const {scheduleEventType, remind, repeatEndDate, repeatIsOver,
      repeatType, remark, invitees, isCreator} = scheduleDetail;
    const repeatObj = {repeatEndDate, repeatIsOver, repeatType};
    const isEdit = (Object.keys(scheduleDetail).length > 0 && !this.props.scheduleInfo.createDate && this.props.scheduleInfo.scheduleId ) ||
      (Object.keys(this.props.editInfo).length > 0 && this.props.editInfo.eventId && this.props.editInfo.eventId !== '' );
    const disabled = isEdit && !this.state.detailEdit;
    const operation = this.state.editRepeatType === 'current' ? this.repeatBtn : this.btn;
    return <div className={`${css.caEdBody} ${css.modalAnimate}`}>
      <header className={css.comPadding}>
        <span className={css.headerText}>{disabled ? '事件详情' : isEdit ? '编辑事件' : '新增事件'}</span>
        <i
          className={`kccfont i-close ${css.headerIcon}`}
          onClick={this.props.closeCalendar}
        />
      </header>
      <div className={css.caEdContent}>
        <Scroll autoHeight>
          <div className={`${css.caEdEvent} ${css.comPadding}`}>
            <p className={css.caEdTitle}>事件内容</p>
            <Textarea
              style={this.inputStyle}
              autosize={{ minRows: 1.2, maxRows: 6 }}
              value={this.state.inputValue}
              disabled={disabled}
              placeholder="你准备做点什么"
              onChange={e => {this.handleChange(e)}}
              maxLength="50"
            />
            <span className={css.eventNum}>
              {this.state.inputValue.length}/50
            </span>
          </div>
          <div className={`${css.caEdTime} ${css.comPadding}`}>
            <p className={css.caEdTitle}>起止时间</p>
            <div className={css.cdEdTimeEdit}>
              <span
                className={`kccfont ${this.state.allDay ? 'i-xuanzhong1' : 'i-xuanzhong'} ${css.timeIcon}`}
                onClick={!disabled ? () => {this.setState({allDay: !this.state.allDay})} : null}
                style={disabled ? {cursor: 'not-allowed'} : {}}
              />
              <span
                className={css.allDay}
                onClick={!disabled ? () => {this.setState({allDay: !this.state.allDay})} : null}
                style={disabled ? {cursor: 'not-allowed'} : {}}
              >
                全天
              </span>
              <DatePicker
                size='small'
                showTime={!this.state.allDay}
                locale={locale}
                format={this.state.allDay ? "YYYYMMDD" : "YYYYMMDD HH:mm"}
                placeholder="开始时间"
                showToday={this.state.allDay}
                value={this.state.beginTime}
                disabled={disabled}
                disabledDate={this.disableBegin}
                onChange={(data, dateString) => {this.onStartChange(data, dateString)}}
              />
              &nbsp;至&nbsp;
              <DatePicker
                size='small'
                showTime={!this.state.allDay}
                locale={locale}
                format={this.state.allDay ? "YYYYMMDD" : "YYYYMMDD HH:mm"}
                placeholder="结束时间"
                showToday={this.state.allDay}
                value={this.state.endTime}
                disabled={disabled}
                disabledDate={this.disableEnd}
                onChange={(data, dateString) => {this.onEndChange(data, dateString)}}
              />
            </div>
          </div>
          {/* 事件类型 */}
          <EventType
            modalShow={this.state.modalShow}
            closeModal={this.closeModal}
            isCloseEvent={this.closeEvent}
            showDefined={this.state.showDefined}
            scheduleEventType={scheduleEventType}
            disabled={disabled}
          />
          {/* 提醒 */}
          {
            this.state.isRemind ?
              <Notice
                closeBtn={this.choiceBtn}
                modalShow={this.state.modalShow}
                closeModal={this.closeModal}
                isAllDay={this.state.allDay}
                disabled={disabled}
                remind={remind}
              /> : null
          }
          {/* 重复方式 */}
          {
            this.state.isRepeat ?
              <Repeat
                closeBtn={this.choiceBtn}
                modalShow={this.state.modalShow}
                closeModal={this.closeModal}
                disabled={disabled}
                repeatObj={repeatObj}
              /> : null
          }
          {/* 参与人 */}
          {
            this.state.isContractor ?
              <Participants
                closeBtn={this.choiceBtn}
                addNew={this.addNew}
                disabled={disabled}
                invitees={invitees}
                isCreator={isCreator}
                eventId={this.state.eventId}
              /> : null
          }
          {/* 备注 */}
          {
            this.state.isRemark ?
              <Remark
                closeBtn={this.choiceBtn}
                disabled={disabled}
                remark={remark}
              /> : null
          }
        </Scroll>
      </div>
      {/* 操作 */}
      <div className={`${css.calendarFootEdit}`}>
        {
          disabled && isCreator === '1' ?
            <button onClick={this.editEvent}>编辑</button> : null
        }
        {
          disabled ?
            <button onClick={() => {this.deleteEvent()}}>删除</button> : null
        }
      </div>
      {
        !disabled ?
          <div className={`${css.calendarFoot}`}>
            <ul>
              {
                operation.map(item =>
                  <li
                    key={item.icon}
                    className={this.state[item.type] ? `${css.active}` : ''}
                    onClick={() => {this.choiceBtn(item.type)}}
                  >
                    <i className={item.icon}/>
                    <span>{item.name}</span>
                  </li>)
              }
            </ul>
            {
              this.state.isSubmit ?
                <div className={css.loadBtn}>
                  <Loading />
                </div> :
                <button onClick={this.saveCalendar}>{this.state.eventId !== '' ? '保存' : '确认'}</button>
            }
          </div> : null
      }
      {/* 遮罩 */}
      {
        this.state.modalShow ?
          <div
            className={css.calendarModal}
            onClick={this.closeModal}
          /> : null
      }
      {/* 自定义事件 */}
      {
        this.state.showDefined ?
          <UserDefinedEvent
            closeEvent={this.closeEvent}
            httpAgent={this.props.httpAgent}
          /> : null
      }
      {/* 添加参与人 */}
      {
        this.state.addItem ?
          <AddContacter
            addNew={this.addNew}
            httpAgent={this.props.httpAgent}
          /> : null
      }
      {/* 编辑重复事件 */}
      {
        this.state.editShow ?
          <Modal
            show
          >
            <EditRepeatSchedule
              closeModal={() => {this.isShowEdit('hide')}}
            />
          </Modal> : null
      }
      {/* 删除重复事件 */}
      {
        this.state.delShow ?
          <Modal
            show
          >
            <DeleteRepeatSchedule
              closeModal={() => {this.isShowDel('hide')}}
              deleteRepeat={this.deleteApi}
            />
          </Modal> : null
      }
    </div>
  }
}