/**
 * Created by Berlin on 2018/6/28.
 */
import React from 'react';
import {inject, observer} from "mobx-react"
import css from '../calendarEditor.scss';
import {Scroll} from 'karaui';

@inject('calendarStore')
@inject('definedFunc')
@observer
export default class EventType extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      showList: false, // 显示类型列表
      event: {},
      eventId: '',
    }
  }

  componentWillReceiveProps(next) {
    // 设置详情事件类型
    if (this.props.scheduleEventType !== next.scheduleEventType && next.scheduleEventType) {
      this.props.definedFunc.setEventType(next.scheduleEventType.id)
      this.setState({ event: next.scheduleEventType, eventId: next.scheduleEventType.id })
    }
    if (this.props.modalShow !== next.modalShow && next.modalShow === false) {
      this.setState({ showList: false })
    }
  }

  componentDidUpdate() {
    const {calendarStore} = this.props;
    const {eventLists} = calendarStore
    // 加唯一setState判断，避免死循环
    if (eventLists && eventLists.length !== 0 && Object.keys(this.state.event).length === 0) {
      this.props.definedFunc.setEventType(eventLists[0].id)
      this.setState({ event: eventLists[0], eventId: eventLists[0].id })
    }
  }

  // 展开
  flodList = () => {
    this.props.closeModal('show');
    this.setState({ showList: true })
  }

  closeList = (e) => {
    e.stopPropagation();
    this.setState({ showList: false })
  }

  handleExpent = (e) => {
    if (!this.props.disabled) {
      if (this.state.showList) {
        this.closeList(e)
      } else {
        this.flodList(e)
      }
    } else {
      return false
    }
  }

  // 选择事件类型
  selectEvent = item => {
    this.setState({ eventId: item.id, event: item, showList: false });
    this.props.definedFunc.setEventType(item.id)
    this.props.closeModal()
  }

  render() {
    const {calendarStore, disabled} = this.props;
    const {eventLists} = calendarStore;
    return <div className={`${css.eventType} ${css.comPadding}`}>
      <p className={css.caEdTitle}>事件类型</p>
      <div
        className={css.eventTypeSelect}
        onClick={(e) => {this.handleExpent(e)}}
        style={disabled ? {cursor: 'not-allowed'} : {}}
      >
        <span
          className={`kccfont ${this.state.event.icon} ${css.eventTypeIcon}`}
          style={{color: this.state.event.color}}
        />
        <span
          className={css.eventTypeName}
        >
          {this.state.event.etname}
        </span>
        <span className={`kccfont ${!this.state.showList ? `i-open ${css.expendIcon}` : `i-close1 ${css.expendClose}`}`}/>
      </div>
      <div className={css.eventTypeLists} style={this.state.showList ? {} : {display: 'none'}}>
        <div>
          <Scroll autoHeight>
            <ul>
              {
                eventLists ? eventLists.map(item =>
                  <li
                    key={item.id}
                    onClick={() => { this.selectEvent(item) }}
                  >
                    <span
                      className={`kccfont i-xuanzhong1 ${css.typeCheck} ${this.state.eventId === item.id ? css.active : ''}`}
                    />
                    <span className={`kccfont ${item.icon}`} style={{ color: item.color }}/>
                    &nbsp;{item.etname}
                  </li>
                ): null
              }
            </ul>
          </Scroll>
        </div>
        <div
          className={`${css.typeFree}`}
          onClick={() => {this.props.isCloseEvent('show')}}
        >自定义</div>
      </div>
    </div>
  }
}