/**
 * Created by Berlin on 2018/6/28.
 */
import React from 'react';
import DatePicker from 'antd/lib/date-picker'
import {inject, observer} from "mobx-react"
import 'antd/lib/date-picker/style/css'
import locale from 'antd/lib/date-picker/locale/zh_CN';
import moment from 'moment';
import 'moment/locale/zh-cn';
import css from '../calendarEditor.scss';

@inject('definedFunc')
@observer

export default class Notice extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      showList: false,
      open: false,
      time: ['ten_minutes'], // 提醒时间
      timeName: ['提前10分钟'],
      diyTime: [], // 自定义时间
      type: [
        'bot',
        'sms'
      ], // 提醒方式
      repeatEndDate: '', // 重复结束时间
    }
    this.dataStyle = {
      position: 'absolute',
      visibility: 'hidden',
    }
    this.noticeTime = [
      { name: '开始时间', value: 'on_time' },
      { name: '提前5分钟', value: 'five_minutes' },
      { name: '提前10分钟', value: 'ten_minutes' },
      { name: '提前30分钟', value: 'thirty_minutes' },
      { name: '提前一天', value: 'one_day' },
    ];
    this.noticeAll = [
      { name: '当天 08:00', value: 'on_eight' },
      { name: '当天 09:00', value: 'on_nine' },
      { name: '一天前 08:00', value: 'pre_eight' },
      { name: '一天前 09:00', value: 'pre_nine' },
      { name: '一周前 08:00', value: 'pre_week_eight' },
    ];
    this.noticeType = [
      { name: 'BOT', code: 'bot'},
      { name: '短信', code: 'sms'},
      { name: '邮件', code: 'email'},
    ]
  }

  componentWillMount() {
    if (this.props.isAllDay) {
      // 全天
      this.setState({ time: ['on_eight'], timeName: ['当天 08:00'] })
      this.saveTime(['on_eight']);
    } else {
      // 非全天
      this.setState({ time: ['ten_minutes'], timeName: ['提前10分钟'] })
      this.saveTime(['ten_minutes']);
    }
    this.saveTypes(this.state.type)
  }

  componentDidMount() {
    if (this.props.remind) {
      const {remindTypes, remindTags} = this.props.remind
      if (remindTypes) {
        this.setState({ type: remindTypes })
        this.saveTypes(remindTypes)
      }
      if (remindTags) {
        const timeArr = this.props.isAllDay ? this.noticeAll : this.noticeTime;
        let time = [];
        let name = [];
        remindTags.forEach(a => {
          if (a.remindTag === 'custom_time') {
            this.choiceTime(a.customizedRemindTime)
          } else {
            timeArr.forEach(item => {
              if (item.value === a.remindTag) {
                time.push(item.value)
                name.push(item.name)
              }
            })
            this.setState({time: time, timeName: name})
            this.saveTime(time.concat(this.state.diyTime))
          }
        })
      }
    }
  }

  componentWillReceiveProps(next) {
    if (this.props.modalShow !== next.modalShow && !next.modalShow) {
      this.setState({ showList: false, open: false })
    }

    if (this.props.isAllDay !== next.isAllDay ) {
      if (next.isAllDay) {
        // 全天
        this.setState({ time: ['on_eight'], timeName: ['当天 08:00'] })
        this.saveTime(['on_eight']);
      } else {
        // 非全天
        this.setState({ time: ['ten_minutes'], timeName: ['提前10分钟'] })
        this.saveTime(['ten_minutes']);
      }
    }
  }

  // 保存时间
  saveTime = (arr) => {
    this.props.definedFunc.setNoticeTime(arr);
  }

  // 保存类型
  saveTypes = (arr) => {
    this.props.definedFunc.setNoticeType(arr);
  }

  // 展开
  flodList = (e) => {
    if (e) {
      e.stopPropagation;
      e.cancelBubble;
    }
    this.props.closeModal('show');
    this.setState({ showList: true })
  }

  closeList = (e) => {
    if (e) {
      e.stopPropagation;
      e.cancelBubble;
    }
    this.setState({ showList: false })
  }

  // 自定义时间
  choiceTime = (e) => {
    let date = e;
    if (typeof e !== 'object') {
      date = moment(e)
    }
    const time = moment(date).format('YYYYMMDD HH:mm:ss');
    let arr = [time];
    this.props.closeModal()
    this.setState({ open: false, diyTime: arr });
    this.saveTime(arr.concat(this.state.time))
  }

  disableBegin = (start) => {
    if (!start) {
      return false;
    }
    const startVal = moment(start).set({ hour: 0, minute: 0, second: 0 });
    const current = moment();
    if (current.get('year') === startVal.get('year') && current.get('month') === startVal.get('month') && current.get('date') === startVal.get('date')) {
      return false;
    }
    return start.valueOf() <= current.valueOf();
  }

  // 选择提醒方式
  typeFunc = (item) => {
    let arr = this.state.type
    if (this.state.type.indexOf(item.code) !== -1) {
      arr.splice(this.state.type.indexOf(item.code), 1)
      this.setState({ type: arr })
      this.saveTypes(arr);
    } else {
      const arr = this.state.type.concat([item.code])
      this.setState({ type: arr })
      this.saveTypes(arr);
    }
  }

  // 选择时间
  timeFunc = (item) => {
    let timeArr = this.state.time;
    let nameArr = this.state.timeName;
    const findTime = timeArr.indexOf(item.value);
    const findName = nameArr.indexOf(item.name);
    const diyTime = this.state.diyTime;
    // 时间value
    if (findTime !== -1) {
      timeArr.splice(findTime, 1)
      this.setState({ time: timeArr })
      this.saveTime(timeArr.concat(diyTime))
    } else {
      timeArr.push(item.value);
      this.setState({ time: timeArr })
      this.saveTime(timeArr.concat(diyTime))
    }
    // 时间name
    if (findName !== -1) {
      nameArr.splice(findName, 1)
      this.setState({ timeName: nameArr })
      // this.saveTime(nameArr.concat(diyTime))
    } else {
      nameArr.push(item.name);
      this.setState({ timeName: nameArr })
      // this.saveTime(nameArr.concat(diyTime))
    }
  }

  // 删除自定义时间
  deleteTime = (e, item) => {
    if (this.props.disabled) {
      return false
    }
    if (e) {
      e.stopPropagation;
      e.cancelBubble;
    }
    const find = this.state.diyTime.indexOf(item)
    let arr = this.state.diyTime
    arr.splice(find, 1)
    this.setState({ diyTime: arr })
    this.saveTime(arr.concat(this.state.time))
  }


  render() {
    const {isAllDay, disabled} = this.props;
    const noticeArr = isAllDay ? this.noticeAll : this.noticeTime;
    return <div className={`${css.noticeBody} ${css.comPadding}`}>
      {
        !disabled ?
          <span
            className={`kccfont i-close ${css.closeNotice}`}
            onClick={(e) => {
              this.props.closeBtn('isRemind')
            }}
          /> : null
      }
      <p className={css.caEdTitle}>提醒</p>
      <div
        className={css.eventTypeSelect}
        style={disabled ? {cursor: 'not-allowed'} : {}}
        onClick={(e) =>{
          if (!disabled) {
            if (this.state.showList) {
              this.closeList(e)
            } else {
              this.flodList(e)
            }
          }
        }}
      >
        {
          this.state.timeName ? this.state.timeName.map((item, idx) =>
            <span
              key={idx}
              className={css.eventTypeName}
            >
              {item}{this.state.timeName.length === idx + 1 ? '' : '，'}
            </span>
          ) : null
        }
        {
          this.state.diyTime ? this.state.diyTime.map((item, idx) =>
            <span
              key={idx}
              className={css.eventDiyName}
            >
              {item}
              <span
                className={`kccfont i-close`}
                onClick={(e) => {this.deleteTime(e, item)}}
              />
            </span>
            ) : null
        }
        {this.state.timeName.length === 0 && this.state.diyTime.length === 0 ? '请选则提醒方式' : null}
        <span
          className={`kccfont ${!this.state.showList ? `i-open ${css.expendIcon}` : `i-close1 ${css.expendClose}`}`}
        />
      </div>
      <div className={css.eventTypeLists} style={this.state.showList ? {} : {display: 'none'}}>
        <ul>
          {
            noticeArr.map((item, idx) =>
              <li
                key={idx}
                onClick={() => { this.timeFunc(item) }}
              >
                <span
                  className={`kccfont i-xuanzhong1 ${this.state.time.indexOf(item.value) === -1 ? '' : css.active} ${css.typeCheck}`}
                />
                {item.name}
              </li>
            )
          }
          <li className={css.noticePicker}>
            <span className={`kccfont i-clock ${css.typeCheck} ${this.state.open ? css.active : ''}`}  onClick={() => {this.setState({ open: true })}}/>
            指定时间
            <DatePicker
              placeholder=""
              open={this.state.open}
              style={this.dataStyle}
              disabledDate={this.disableBegin}
              showTime
              locale={locale}
              format="YYYY-MM-DD HH:mm"
              onOk={(e) => {this.choiceTime(e)}}
            />
          </li>
        </ul>
      </div>
      <ul className={`${css.evenNoticeType} ${css.clearfix}`}>
        {this.noticeType.map(item =>
          <li
            key={item.code}
            onClick={() => {if (!disabled) {this.typeFunc(item)}}}
            style={disabled ? {cursor: 'not-allowed'} : {}}
          >
            <span className={`kccfont ${ this.state.type.indexOf(item.code) !==-1 ? 'i-xuanzhong1' : 'i-xuanzhong' }`}/>
            <span className={css.typeText}>&nbsp;{item.name}</span>
          </li>
        )}
      </ul>
    </div>
  }
}