import React from 'react';
import style from './addContacter.scss';
import SearchResultItem from './searchResultItem';
import SelectedItem from './selectedItem';
import {inject, observer} from "mobx-react";

@inject('contractor')
@inject('definedFunc')
@observer

export default class AddContacter extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      showSearchResults: false, // 搜索关键字为空时，添加选项时 = false, onFocus&onChange = true
      selectedList: new Map(),
      first: true,
    };
  }
  componentWillReceiveProps = (nextProps) => {
    const { searchInfo } = nextProps.contractor;
    if (searchInfo && searchInfo.result && searchInfo.result.length > 0) {
      this.setState({ showSearchResults: true });
    }
  }
  handleOnChange = () => {
    const {searchRecent, searchLists} = this.props.contractor;
    const keyword = this.input && this.input.value ? this.input.value.trim() : null;
    if(keyword && keyword !== '') {
      this.props.httpAgent.searchResult(keyword, 1, 10).then(res => {
        searchLists(res)
      });
    } else {
      this.props.httpAgent.recentInvitees().then(res => {
        if (res.resultCode === '000000') {
          searchRecent(res)
        }
    });;
    }
  }
  handleOnFocus = () => {
    const keyword = this.input && this.input.value ? this.input.value.trim() : null;
    const {searchRecent, searchLists} = this.props.contractor;
    if(keyword && keyword !== '') {
      this.props.httpAgent.searchResult(keyword, 1, 10).then(res => {
        searchLists(res)
      });
      this.setState({ showSearchResults: true });
    } else {
      this.props.httpAgent.recentInvitees().then(res => {
        if (res.resultCode === '000000') {
          searchRecent(res)
        }
      });
      this.setState({ showSearchResults: true });
    }
  }
  handleOnBlur = () => {
    const that = this;
    const { timer } = this;
    if (timer) clearTimeout(timer);
    this.timer = setTimeout(() => {
      that.setState({ showSearchResults: false });
    }, 200);
  }
  selectItem = (id, item) => {
    const selectedList = this.state.selectedList;
    if (!selectedList.has(id)) {
      selectedList.set(id, item);
    }
    this.setState({ selectedList });
    this.hideSearchResults();
  }
  removeItem = (id, item) => {
    const selectedList = this.state.selectedList;
    if (selectedList.has(id)) {
      selectedList.delete(id, item);
    }
    this.setState({ selectedList });
  }
  hideSearchResults = () => {
    this.setState({ showSearchResults: false });
  }
  save = () => {
    const selectedList = Array.from(this.state.selectedList.values());
    let staffList = [];
    selectedList.forEach((item) => {
      staffList.push(item.id);
    });
    this.props.definedFunc.saveSelected(selectedList);
  }
  cleanSearch = () => {
    if (this.input) this.input.value = '';
  }
  render() {
    const searchInfo = this.props.contractor.searchInfo;
    const searchResults = this.props.contractor.searchResults;
    const { showSearchResults } = this.state;
    const selectedList = Array.from(this.state.selectedList.values());
    const showNoResult = (showSearchResults && searchResults.length === 0 && (this.input === undefined || this.input.value !== ''));
    const closeIcon = (this.input && this.input.value !== '') ? `${style.closeShow}` : `${style.closeShow} ${style.hide}` ;
    const inputValue = this.input ? this.input.value : null;
    return (<div className={style.content}>
      <div className={style.addTitle}>
        <span className={style.title}>添加参与人</span>
        <i
          className={'kccfont i-close'}
          onClick={() => {
            this.props.addNew('close');
          }}
        />
      </div>
      <div className={style.search}>
        <i className={'kccfont i-search'} />
        <input
          type="text"
          placeholder="输入姓名或NT账号"
          ref={(e) => { this.input = e; }}
          onChange={() => { this.handleOnChange(); }}
          onFocus={() => { this.handleOnFocus(); }}
          onBlur={() => { this.handleOnBlur(); }}
        />
        <span
          className={`kccfont i-close ${closeIcon}`}
          onClick={() => { this.cleanSearch(); }}
        />
      </div>
      <SearchResultItem
        searchResults={searchResults} show={showSearchResults} showNoResult={showNoResult}
        selectItem={this.selectItem} selectedList={selectedList} searchResult={this.props.httpAgent.searchResult}
        searchInfo={searchInfo} inputValue={inputValue} cleanSearch={this.cleanSearch}
      />
      <SelectedItem
        selectedList={selectedList}
        removeItem={this.removeItem}
        save={this.save}
        addNew={this.props.addNew}
      />
    </div>);
  }
}
