import React from 'react';
import style from './searchResultItem.scss';
import {Scroll} from 'karaui';
import {inject, observer} from "mobx-react";

@inject('contractor')
@observer

export default class SearchResultItem extends React.Component {
  getCommonElements = (arr1, arr2, property) => {
    if (Array.isArray(arr1) && Array.isArray(arr2)) {
      let newMap = new Map();
      const newArr = arr1.concat(arr2);
      newArr.forEach((ele) => {
        const key = ele[property] ? ele[property] : null;
        if (!key) return false;
        if (newMap.has(key)) {
          newMap.set(key, newMap.get(key) + 1);
        } else {
          newMap.set(key, 1);
        }
        return ele;
      });
      return newMap;
    }
    return new Map();
  }
  getSelectedItems = () => {
    const { searchResults, selectedList } = this.props;
    const searchArr = searchResults.sort()
    return this.getCommonElements(searchArr, selectedList, 'accountId');
  }
  selectItem = (item) => {
    this.props.selectItem(item.accountId, {
      accountId: item.accountId,
      accountName: item.accountName,
      headIcon: item.headIcon,
    });
  }
  handleScroll = () => {
    const { inputValue } = this.props;
    const { pageSize, count, pageNo } = this.props.searchInfo;
    if (pageNo <= (Math.floor(count / pageSize) + 1)) {
      this.props.searchResult(inputValue, pageNo + 1).then(res => {
        if (res && res.resultCode === '000000') {
          this.props.contractor.searchLists(res)
        }
      });
    }
  }
  render() {
    const { searchResults, show, showNoResult } = this.props;
    if (!show) {
      return <div className={style['n-hidden']} />;
    } else if (showNoResult) {
      return (
        <div className={style['no-result']}>
          <p/>
        </div>
      );
    }
    const contentHgt = 72 * searchResults.length;
    const commonItemMap = this.getSelectedItems();
    return (
      <div className={style['m-list']} style={{ height: `${contentHgt}px` }}>
        <Scroll
          onWheelBottom={() => { this.handleScroll(); }}
        >
          <ul>
            {
              searchResults.map((item) => {
                const that = this;
                const isAdded = (commonItemMap && commonItemMap.get(item.accountId) > 1);
                return (
                  <li
                    key={item.accountId}
                    onClick={() => {
                      that.selectItem(item);
                      that.props.cleanSearch();
                    }}
                  >
                    <img src={item.headIcon} alt="item.name" onError={this.useDefaultPic} />
                    {
                      item.accountType === 'External' ?
                        <div className={isAdded ? `${style['l-info-staff']} ${style.added}` : style['l-info-staff']}>
                          <p className={style.extenal}>
                            <span>{item.accountName}({item.staffAccount})</span>
                          </p>
                        </div>
                        :
                        <div className={isAdded ? `${style['l-info-staff']} ${style.added}` : style['l-info-staff']}>
                          <p><span>{item.accountName}({item.staffAccount})</span></p>
                          <p className={style.addDetailInfo}>
                            <span className={style.location}>{item.orgName}</span>
                            <br/>
                            <span className={style.manager}>上级经理：{item.parentStaffName}</span>
                            <span className={isAdded ? style.isAdded : style['n-hidden']}>已添加</span>
                          </p>
                        </div>
                    }
                  </li>
                );
              })
            }
          </ul>
        </Scroll>
      </div>);
  }
}
