/**
 * Created by Berlin on 2018/6/29.
 */
import React from 'react';
import DatePicker from 'antd/lib/date-picker'
import {inject, observer} from "mobx-react"
import 'antd/lib/date-picker/style/css'
import locale from 'antd/lib/date-picker/locale/zh_CN';
import moment from 'moment';
import 'moment/locale/zh-cn';
import css from './repeat.scss';

@inject('definedFunc')
@observer

export default class Repeat extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      showList: false,
      repeatIsOver: 'no',
      repeatValue: '',
      repeatText: '请选择重复方式',
      repeatTime: '',
      timeObj: null,
    }
    this.repeatArr = [
      {
        name: '每日',
        value: 'everyday',
      },
      {
        name: '每周',
        value: 'everyweek',
      },
      {
        name: '每月',
        value: 'everymonth',
      },
      {
        name: '每年',
        value: 'everyyear',
      },
    ];
    this.repeatType = [
      { name: '永不结束', code: 'no' },
      { name: '重复至指定时间', code: 'yes' }
    ]
  }

  componentDidMount() {
    const {repeatEndDate, repeatIsOver, repeatType} = this.props.repeatObj
    this.repeatArr.map(item => {
      if (item.value === repeatType) {
        this.setState({repeatText: item.name})
        return
      }
    })
    this.setState({
      repeatTime: repeatEndDate ? repeatEndDate : '',
      repeatIsOver: repeatIsOver ? repeatIsOver : 'no',
      repeatValue: repeatType ? repeatType : '',
      timeObj: repeatEndDate ? moment(repeatEndDate) : moment(new Date().setDate(new Date().getDate() + 1)),
    })
  }

  componentWillReceiveProps(next) {
    if (this.props.modalShow !== next.modalShow && !next.modalShow) {
      this.setState({ showList: false })
    }
  }

  // 不可选择的开始日期
  disableBegin = (start) => {
    if (!start) { return false }
    const startVal = moment(start).set({ day: 1, hour: 0, minute: 0, second: 0 });
    const current = moment();
    if (current.get('year') === startVal.get('year') && current.get('month') === startVal.get('month') && current.get('date') === startVal.get('date')) {
      return false;
    }
    return start.valueOf() < current.valueOf();
  }

  // 展开
  flodList = () => {
    this.props.closeModal('show');
    this.setState({ showList: true })
  }

  closeList = (e) => {
    if (e) { e.stopPropagation(); }
    this.props.closeModal();
    this.setState({ showList: false })
  }

  choiceType = (type) => {
    if (type !== this.state.repeatIsOver) {
      this.props.definedFunc.setRepeatIsOver(type);
      this.setState({ repeatIsOver: type });
    }
  }

  choiceRepeat = (item) => {
    this.setState({repeatValue : item.value, repeatText: item.name})
    this.props.definedFunc.setRepeatType(item.value, this.state.repeatTime)
    this.closeList()
  }

  repeatTime = (e) => {
    let time = moment(e).format('YYYYMMDD 23:59:59')
    if (time === 'Invalid date') {
      time = ''
    }
    this.props.definedFunc.setRepeatType(this.state.repeatValue, time)
    this.setState({ repeatTime: time, timeObj: e })
  }

  render() {
    const {disabled} = this.props;
    return <div className={`${css.caRepeat} ${css.comPadding}`}>
      {
        !disabled ?
          <span className={`kccfont i-close ${css.closeRepeat}`} onClick={() => {this.props.closeBtn('isRepeat')} }/> : null
      }
      <p className={css.caEdTitle}>重复方式</p>
      <div
        className={css.eventTypeSelect}
        style={disabled ? {cursor: 'not-allowed'} : {}}
        onClick={(e) => {
          if (disabled) { return false }
          if (this.state.showList) {
            this.closeList(e)
          } else {
            this.flodList(e)
          }
        }}
      >
        {this.state.repeatText}
        <span className={`kccfont ${!this.state.showList ? `i-open ${css.expendIcon}` : `i-close1 ${css.expendClose}`}`}/>
      </div>
      <div className={css.eventTypeLists} style={this.state.showList ? {} : {display: 'none'}}>
        <ul>
          {
            this.repeatArr.map((item, idx) =>
              <li
                key={idx}
                onClick={() => {this.choiceRepeat(item)}}
              >
                <span
                  className={`kccfont i-xuanzhong1 ${css.typeCheck} ${item.value === this.state.repeatValue ? css.active : ''}`}
                />
                {item.name}
              </li>
            )
          }
        </ul>
      </div>
      <ul className={`${css.evenNoticeType} ${css.clearfix}`}>
        {
          this.state.repeatValue !== '' ? this.repeatType.map(item =>
            <li
              key={item.code}
              style={disabled ? {cursor: 'not-allowed'} : {}}
              onClick={disabled ? null : () => {
                this.choiceType(item.code)
              }}
            >
              <span className={`kccfont ${this.state.repeatIsOver === item.code ? 'i-xuanzhong1' : 'i-xuanzhong' }`}/>
              <span className={css.typeText}>&nbsp;{item.name}</span>
            </li>) : null
        }
        {
          this.state.repeatIsOver === 'yes' ?
            <li>
              <DatePicker
                size='small'
                locale={locale}
                disabledDate={this.disableBegin}
                onChange={(e) => {this.repeatTime(e)}}
                disabled={disabled}
                value={this.state.timeObj}
              />
            </li> : null
        }
      </ul>
    </div>
  }
}